@@ -6,9 +6,9 @@ using namespace Quotient;
 
 SetRoomStateWithKeyJob::SetRoomStateWithKeyJob(const QString& roomId, const QString& eventType,
                                                const QString& stateKey, const QJsonObject& content)
-    : BaseJob(HttpVerb::Put, QStringLiteral("SetRoomStateWithKeyJob"),
+    : BaseJob(HttpVerb::Put, u"SetRoomStateWithKeyJob"_s,
               makePath("/_matrix/client/v3", "/rooms/", roomId, "/state/", eventType, "/", stateKey))
 {
     setRequestData({ toJson(content) });
-    addExpectedKey("event_id");
+    addExpectedKey(u"event_id"_s);
 }
