@@ -64,13 +64,11 @@ QOlmExpected<QOlmSession> QOlmAccount::createInbound(
     return session;
 }
 
-QOlmAccount::QOlmAccount(QStringView userId, QStringView deviceId,
-                         QObject* parent)
+QOlmAccount::QOlmAccount(QString userId, QString deviceId, QObject* parent)
     : QObject(parent)
-    , olmDataHolder(
-          makeCStruct(olm_account, olm_account_size, olm_clear_account))
-    , m_userId(userId.toString())
-    , m_deviceId(deviceId.toString())
+    , olmDataHolder(makeCStruct(olm_account, olm_account_size, olm_clear_account))
+    , m_userId(std::move(userId))
+    , m_deviceId(std::move(deviceId))
 {}
 
 void QOlmAccount::setupNewAccount()
@@ -101,8 +99,7 @@ QByteArray QOlmAccount::pickle(const PicklingKey& key) const
     if (olm_pickle_account(olmData, key.data(), key.size(),
                            pickleBuffer.data(), pickleLength)
         == olm_error())
-        QOLM_INTERNAL_ERROR(qPrintable("Failed to pickle Olm account "_ls
-                                       + accountId()));
+        QOLM_INTERNAL_ERROR("Failed to pickle Olm account "_L1 + accountId());
 
     return pickleBuffer;
 }
@@ -113,12 +110,10 @@ IdentityKeys QOlmAccount::identityKeys() const
     auto keyBuffer = byteArrayForOlm(keyLength);
     if (olm_account_identity_keys(olmData, keyBuffer.data(), keyLength)
         == olm_error()) {
-        QOLM_INTERNAL_ERROR(
-            qPrintable("Failed to get "_ls % accountId() % " identity keys"_ls));
+        QOLM_INTERNAL_ERROR("Failed to get "_L1 % accountId() % " identity keys"_L1);
     }
     const auto key = QJsonDocument::fromJson(keyBuffer).object();
-    return { key.value(QStringLiteral("curve25519")).toString(),
-             key.value(QStringLiteral("ed25519")).toString() };
+    return { key.value("curve25519"_L1).toString(), key.value("ed25519"_L1).toString() };
 }
 
 QByteArray QOlmAccount::sign(const QByteArray &message) const
@@ -143,14 +138,12 @@ QByteArray QOlmAccount::signIdentityKeys() const
 {
     const auto keys = identityKeys();
     static const auto& Algorithms = toJson(SupportedAlgorithms);
-    return sign(QJsonObject{
-        { "algorithms"_ls, Algorithms },
-        { "user_id"_ls, m_userId },
-        { "device_id"_ls, m_deviceId },
-        { "keys"_ls,
-          QJsonObject{
-              { QStringLiteral("curve25519:") + m_deviceId, keys.curve25519 },
-              { QStringLiteral("ed25519:") + m_deviceId, keys.ed25519 } } } });
+    return sign(
+        QJsonObject{ { u"algorithms"_s, Algorithms },
+                     { u"user_id"_s, m_userId },
+                     { u"device_id"_s, m_deviceId },
+                     { u"keys"_s, QJsonObject{ { "curve25519:"_L1 + m_deviceId, keys.curve25519 },
+                                               { "ed25519:"_L1 + m_deviceId, keys.ed25519 } } } });
 }
 
 size_t QOlmAccount::maxNumberOfOneTimeKeys() const
@@ -166,8 +159,7 @@ size_t QOlmAccount::generateOneTimeKeys(size_t numberOfKeys)
         olmData, numberOfKeys, getRandom(randomLength).data(), randomLength);
 
     if (result == olm_error())
-        QOLM_INTERNAL_ERROR(qPrintable(
-            "Failed to generate one-time keys for account "_ls + accountId()));
+        QOLM_INTERNAL_ERROR("Failed to generate one-time keys for account "_L1 + accountId());
 
     emit needsSave();
     return result;
@@ -181,8 +173,7 @@ UnsignedOneTimeKeys QOlmAccount::oneTimeKeys() const
     if (olm_account_one_time_keys(olmData, oneTimeKeysBuffer.data(),
                                   oneTimeKeyLength)
         == olm_error())
-        QOLM_INTERNAL_ERROR(qPrintable(
-            "Failed to obtain one-time keys for account"_ls % accountId()));
+        QOLM_INTERNAL_ERROR("Failed to obtain one-time keys for account"_L1 % accountId());
 
     const auto json = QJsonDocument::fromJson(oneTimeKeysBuffer).object();
     UnsignedOneTimeKeys oneTimeKeys;
@@ -193,11 +184,11 @@ UnsignedOneTimeKeys QOlmAccount::oneTimeKeys() const
 OneTimeKeys QOlmAccount::signOneTimeKeys(const UnsignedOneTimeKeys &keys) const
 {
     OneTimeKeys signedOneTimeKeys;
-    for (const auto& [keyId, key] : asKeyValueRange(keys.curve25519()))
-        signedOneTimeKeys.insert("signed_curve25519:"_ls % keyId,
+    for (const auto& [keyId, key] : keys.curve25519().asKeyValueRange())
+        signedOneTimeKeys.insert("signed_curve25519:"_L1 % keyId,
                                  SignedOneTimeKey {
                                      key, m_userId, m_deviceId,
-                                     sign(QJsonObject { { "key"_ls, key } }) });
+                                     sign(QJsonObject { { "key"_L1, key } }) });
     return signedOneTimeKeys;
 }
 
@@ -206,7 +197,7 @@ OlmErrorCode QOlmAccount::removeOneTimeKeys(const QOlmSession& session)
     if (olm_remove_one_time_keys(olmData, session.olmData) == olm_error()) {
         qWarning(E2EE).nospace()
             << "Failed to remove one-time keys for session "
-            << session.sessionId() << ": "_ls << lastError();
+            << session.sessionId() << ": "_L1 << lastError();
         return lastErrorCode();
     }
     emit needsSave();
@@ -223,10 +214,10 @@ DeviceKeys QOlmAccount::deviceKeys() const
         .userId = m_userId,
         .deviceId = m_deviceId,
         .algorithms = Algorithms,
-        .keys{ { "curve25519:"_ls + m_deviceId, idKeys.curve25519 },
-               { "ed25519:"_ls + m_deviceId, idKeys.ed25519 } },
+        .keys{ { "curve25519:"_L1 + m_deviceId, idKeys.curve25519 },
+               { "ed25519:"_L1 + m_deviceId, idKeys.ed25519 } },
         .signatures{ { m_userId,
-                       { { "ed25519:"_ls + m_deviceId,
+                       { { "ed25519:"_L1 + m_deviceId,
                            QString::fromLatin1(signIdentityKeys()) } } } }
     };
 }
@@ -255,17 +246,16 @@ QOlmExpected<QOlmSession> QOlmAccount::createOutboundSession(
     const QByteArray& theirIdentityKey, const QByteArray& theirOneTimeKey) const
 {
     QOlmSession olmOutboundSession{};
-    if (const auto randomLength = olm_create_outbound_session_random_length(
-            olmOutboundSession.olmData);
-        olm_create_outbound_session(
-            olmOutboundSession.olmData, olmData, theirIdentityKey.data(),
-            theirIdentityKey.length(), theirOneTimeKey.data(),
-            theirOneTimeKey.length(), getRandom(randomLength).data(),
-            randomLength)
+    if (const auto randomLength =
+            olm_create_outbound_session_random_length(olmOutboundSession.olmData);
+        olm_create_outbound_session(olmOutboundSession.olmData, olmData, theirIdentityKey.data(),
+                                    unsignedSize(theirIdentityKey), theirOneTimeKey.data(),
+                                    unsignedSize(theirOneTimeKey), getRandom(randomLength).data(),
+                                    randomLength)
         == olm_error()) {
         const auto errorCode = olmOutboundSession.lastErrorCode();
         QOLM_FAIL_OR_LOG_X(errorCode == OLM_NOT_ENOUGH_RANDOM,
-                         "Failed to create an outbound Olm session"_ls,
+                           "Failed to create an outbound Olm session"_L1,
                            olmOutboundSession.lastError());
         return errorCode;
     }
@@ -282,7 +272,7 @@ bool Quotient::verifyIdentitySignature(const DeviceKeys& deviceKeys,
                                        const QString& deviceId,
                                        const QString& userId)
 {
-    const auto signKeyId = "ed25519:"_ls + deviceId;
+    const auto signKeyId = "ed25519:"_L1 + deviceId;
     const auto signingKey = deviceKeys.keys[signKeyId];
     const auto signature = deviceKeys.signatures[userId][signKeyId];
 
@@ -298,8 +288,8 @@ bool Quotient::ed25519VerifySignature(const QString& signingKey,
 
     QJsonObject obj1 = obj;
 
-    obj1.remove("unsigned"_ls);
-    obj1.remove("signatures"_ls);
+    obj1.remove("unsigned"_L1);
+    obj1.remove("signatures"_L1);
 
     auto canonicalJson = QJsonDocument(obj1).toJson(QJsonDocument::Compact);
 
